<?php

/*
 * ============================================================================
 * Licensed Materials - Property of IBM
 * Project  Zero
 *
 * (C) Copyright IBM Corp. 2007  All Rights Reserved.
 *
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 * ============================================================================
 */

/*
 * This result handler callback will render a JDBC ResultSet
 * as a JSON-encoded string.  It requires the json_encode function
 * provided by the AuxillaryExtension.  Use this in conjunction
 * with the dataQuery API like this:
 * 
 *   $sql = "SELECT * FROM item";
 *   $callback = "JSONResultHandler";
 *   $result = dataQuery($manager,$sql,$callback,null);
 * 
 * The rendered JSON string will contain an array of maps.  Each
 * map includes the data from a single row, keyed by column name.
 */
function JSONResultHandler($resultSet) {
	
	if (is_null($resultSet)) return null;
	
	$columnCount = dataResultSetGetColumnCount($resultSet);
	$columnNames = array();
	for ($i=1; $i<=$columnCount; $i++) {
		$name = dataResultSetGetColumnName($resultSet,$i);
		$columnNames[$i] = $name;
	}
	
	$rowArray = array();
	while (dataResultSetNext($resultSet)) {
		$row = array();
		for ($i=1; $i<=$columnCount; $i++) {
			$obj = dataResultSetGetObject($resultSet,$i);
			$row[$columnNames[$i]] = $obj;
		}
		$rowArray[] = $row;
	}

	return json_encode($rowArray);
}

?>
